summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2014-08-25 14:31:10 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2014-08-25 14:31:10 -0500
commitf67ba3f31432dcadf96e46b8c39df406f2dd20dc (patch)
tree521b34ca932116b97ac8ca2077a448241e4650f0
parente46e5dfd9d978a0edd96c0898062cc29cde9779e (diff)
downloadtdesudo-f67ba3f3.tar.gz
tdesudo-f67ba3f3.zip
Clean up old KdeSudo strings
-rw-r--r--AUTHORS2
-rw-r--r--ChangeLog12
-rw-r--r--po/fr.po8
-rw-r--r--tdesudo/main.cpp6
-rw-r--r--tdesudo/tdesudo.cpp20
-rw-r--r--tdesudo/tdesudo.h8
6 files changed, 28 insertions, 28 deletions
diff --git a/AUTHORS b/AUTHORS
index 0d7057b..6a63059 100644
--- a/AUTHORS
+++ b/AUTHORS
@@ -1,5 +1,5 @@
Since 05/2007
-The Kubuntu-KdeSudo team:
+The Kubuntu-TdeSudo team:
Martin Böhm <martin.bohm@kubuntu.org>
Anthony Mercatante <tonio@ubuntu.com>
Juan Carlos Torres <carlosdgtorres@gmail.com>
diff --git a/ChangeLog b/ChangeLog
index 1e9fe8b..8d2f8c3 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,26 +1,26 @@
-KdeSudo 2.5.1
+TdeSudo 2.5.1
-----------
* Fixed build issue with gcc 4.3.0
Thanks to "big_gie" at archlinux for the patch
-KdeSudo 2.5
+TdeSudo 2.5
-----------
* Fixed icon/name checking when starting an application by its full
path
* Fixed icon/name checking when using X-KDE-SubstituteUID
-KdeSudo 2.4
+TdeSudo 2.4
-----------
* Deals correctly with antislashed quotes:
- Closes Launchpad #187053
* Fixed segfault due to double pclose() usage.
-KdeSudo 2.3
+TdeSudo 2.3
-----------
* Fixed -u option working randomly, due to missing pclose
call when creating the Xauthority file.
-KdeSudo 2.2
+TdeSudo 2.2
-----------
* A little issue with nonewdcop option has been fixed,
due to sudo removing some environment variables, causing
@@ -61,7 +61,7 @@ tdesudo 2.0
* Added support for -r and -p tdesu cmdline option, for "nice" support
-* KdeSudo closes correctly after 3 bad passwords given
+* TdeSudo closes correctly after 3 bad passwords given
* Fixes kcm modules support
diff --git a/po/fr.po b/po/fr.po
index d94381d..cc12f88 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -16,8 +16,8 @@ msgstr ""
"X-Generator: KBabel 1.11.4\n"
#: main.cpp:27 main.cpp:44
-msgid "KdeSudo"
-msgstr "KdeSudo"
+msgid "TdeSudo"
+msgstr "TdeSudo"
#: main.cpp:33
msgid "sets a runas user"
@@ -35,11 +35,11 @@ msgstr "Commentaire à afficher dans la boite de dialogue"
msgid ""
"No command arguments supplied!\n"
"Usage: tdesudo [-u <runas>] <command>\n"
-"KdeSudo will now exit..."
+"TdeSudo will now exit..."
msgstr ""
"Aucune commande spécifiée en argument!\n"
"Utilisation: tdesudo [-u <runas>] <command>\n"
-"KdeSudo va maintenant se fermer..."
+"TdeSudo va maintenant se fermer..."
#: tdesudo.cpp:28
msgid ""
diff --git a/tdesudo/main.cpp b/tdesudo/main.cpp
index c9b7538..94d095e 100644
--- a/tdesudo/main.cpp
+++ b/tdesudo/main.cpp
@@ -52,7 +52,7 @@ static TDECmdLineOptions options[] =
{ "p <priority>", I18N_NOOP("Process priority, between 0 and 100, 0 the lowest [50]"), 0},
{ "r", I18N_NOOP("Use realtime scheduling"), 0},
{ "f <file>", I18N_NOOP("Use target UID if <file> is not writeable"), 0},
- { "t", I18N_NOOP("Fake option for TDE's KdeSu compatibility"), 0 },
+ { "t", I18N_NOOP("Fake option for TDE's TdeSu compatibility"), 0 },
{ "n", I18N_NOOP("Do not keep password"), 0},
{ "nonewdcop", I18N_NOOP("Use existing DCOP server"), 0},
{ "comment <dialog text>", I18N_NOOP("The comment that should be displayed in the dialog"), 0},
@@ -63,7 +63,7 @@ static TDECmdLineOptions options[] =
int main(int argc, char **argv)
{
- TDEAboutData aboutData("tdesudo", I18N_NOOP("KdeSudo"),
+ TDEAboutData aboutData("tdesudo", I18N_NOOP("TdeSudo"),
VERSION, description, TDEAboutData::License_GPL,
"(c) 2007-2008, Anthony Mercatante", 0, 0, "tonio@ubuntu.com");
aboutData.addAuthor("Robert Gruber",0, "rgruber@users.sourceforge.net");
@@ -138,7 +138,7 @@ int main(int argc, char **argv)
else
name = executable;
- KdeSudo *tdesudo = new KdeSudo(0,0,icon,name,withIgnoreButton);
+ TdeSudo *tdesudo = new TdeSudo(0,0,icon,name,withIgnoreButton);
a.setMainWidget(tdesudo);
args->clear();
diff --git a/tdesudo/tdesudo.cpp b/tdesudo/tdesudo.cpp
index 900d3e5..ac597b9 100644
--- a/tdesudo/tdesudo.cpp
+++ b/tdesudo/tdesudo.cpp
@@ -44,7 +44,7 @@
#include <sys/stat.h>
#include <sys/types.h>
-KdeSudo::KdeSudo(TQWidget *parent, const char *name,const TQString& icon, const TQString& generic, bool withIgnoreButton)
+TdeSudo::TdeSudo(TQWidget *parent, const char *name,const TQString& icon, const TQString& generic, bool withIgnoreButton)
: KPasswordDialog(KPasswordDialog::Password, false, false, icon, parent, name)
{
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
@@ -72,7 +72,7 @@ KdeSudo::KdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
!(!args->isSet("c") && args->count()) &&
!args->isSet("s"))
{
- KMessageBox::information(NULL, i18n("No command arguments supplied!\nUsage: tdesudo [-u <runas>] <command>\nKdeSudo will now exit..."));
+ KMessageBox::information(NULL, i18n("No command arguments supplied!\nUsage: tdesudo [-u <runas>] <command>\nTdeSudo will now exit..."));
noExec = true;
}
@@ -323,11 +323,11 @@ KdeSudo::KdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
p->start( TDEProcess::NotifyOnExit, TDEProcess::All );
}
-KdeSudo::~KdeSudo()
+TdeSudo::~TdeSudo()
{
}
-void KdeSudo::receivedOut(TDEProcess*, char*buffer, int buflen)
+void TdeSudo::receivedOut(TDEProcess*, char*buffer, int buflen)
{
char *pcTmp= new char[buflen+1];
strncpy(pcTmp,buffer,buflen);
@@ -385,7 +385,7 @@ void KdeSudo::receivedOut(TDEProcess*, char*buffer, int buflen)
}
}
-void KdeSudo::procExited(TDEProcess*)
+void TdeSudo::procExited(TDEProcess*)
{
if (!keepPwd && unCleaned)
{
@@ -406,7 +406,7 @@ void KdeSudo::procExited(TDEProcess*)
}
}
-void KdeSudo::slotOk()
+void TdeSudo::slotOk()
{
TQString strTmp(password());
strTmp+="\n";
@@ -414,19 +414,19 @@ void KdeSudo::slotOk()
this->hide();
}
-void KdeSudo::slotUser1()
+void TdeSudo::slotUser1()
{
done(AsUser);
}
-void KdeSudo::blockSigChild()
+void TdeSudo::blockSigChild()
{
sigset_t sset;
sigemptyset(&sset);
sigaddset(&sset, SIGCHLD);
sigprocmask(SIG_BLOCK, &sset, 0L);
}
-void KdeSudo::unblockSigChild()
+void TdeSudo::unblockSigChild()
{
sigset_t sset;
sigemptyset(&sset);
@@ -434,7 +434,7 @@ void KdeSudo::unblockSigChild()
sigprocmask(SIG_UNBLOCK, &sset, 0L);
}
-TQString KdeSudo::validArg(TQString arg)
+TQString TdeSudo::validArg(TQString arg)
{
TQChar firstChar = arg.at(0);
TQChar lastChar = arg.at(arg.length() - 1);
diff --git a/tdesudo/tdesudo.h b/tdesudo/tdesudo.h
index 8545ddf..976a379 100644
--- a/tdesudo/tdesudo.h
+++ b/tdesudo/tdesudo.h
@@ -34,7 +34,7 @@
class KCookie;
/*
* KdeSudo is the base class of the project
*
* It inherits KPasswordDialog and overrrides the
* slot slotOK()
@@ -43,7 +43,7 @@ class KCookie;
* @version 2.4
*/
-class KdeSudo : public KPasswordDialog
+class TdeSudo : public KPasswordDialog
{
Q_OBJECT
@@ -52,12 +52,12 @@ public:
/*
* Default construtor
*/
- KdeSudo(TQWidget* parent=0, const char *name=0, const TQString& icon=TQString(), const TQString& generic=TQString(), bool withIgnoreButton=false);
+ TdeSudo(TQWidget* parent=0, const char *name=0, const TQString& icon=TQString(), const TQString& generic=TQString(), bool withIgnoreButton=false);
/*
* Default destructor
*/
- ~KdeSudo();
+ ~TdeSudo();
enum ResultCodes { AsUser = 10 };
public slots: // Public slots
@@ -34,7 +34,7 @@
class KCookie;
/*
-* KdeSudo is the base class of the project
+* TdeSudo is the base class of the project
*
* It inherits KPasswordDialog and overrrides the